@@ -5,8 +5,9 @@
 #define DOWNLOAD_NO_404              1
 #define DOWNLOAD_KILL_OTHER_REQUESTS 2
 
-void DownloadInit(char *email);
-void ProcessDownloads(unsigned long sleep_time);
+void download_init(char *email);
+void download_process(unsigned long sleep_time);
+int download_kill(char *filename);
 int download_file(char *filename, char *from_addr, char *postdata, int flags, void (*callback)(char *filename, void *data), void *data);
 
 #endif
